OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Upotettu viesti %s",
    "Important mail" : "Tärkeä sähköposti",
    "No message found yet" : "Yhtäkään viestiä ei ole vielä löytynyt",
    "Set up an account" : "Määritä tili",
    "Unread mail" : "Lukematon sähköposti",
    "Important" : "Tärkeä",
    "Work" : "Työ",
    "Personal" : "Henkilökohtainen",
    "To Do" : "Tehtävä",
    "Later" : "Myöhemmin",
    "Mail" : "Sähköposti",
    "Mail Application" : "Sähköpostisovellus",
    "Mails" : "Sähköpostit",
    "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
    "Your session has expired. The page will be reloaded." : "Istuntosi on vanhentunut. Sivu ladataan uudelleen.",
    "Drafts are saved in:" : "Luonnokset tallennetaan sijaintiin:",
    "Sent messages are saved in:" : "Lähetetyt viestit tallennetaan sijaintiin:",
    "Deleted messages are moved in:" : "Poistetut viestit tallennetaan sijaintiin:",
    "Archived messages are moved in:" : "Siirrä arkistoidut viestit:",
    "Connecting" : "Yhdistetään",
    "Reconnect Google account" : "Yhdistä Google-tili uudelleen",
    "Sign in with Google" : "Kirjaudu sisään Google-tililläsi",
    "Reconnect Microsoft account" : "Yhdistä Microsoft-tili uudelleen",
    "Sign in with Microsoft" : "Kirjaudu Microsoft-tilillä",
    "Save" : "Tallenna",
    "Connect" : "Yhdistä",
    "Looking up configuration" : "Etsitään määrityksiä",
    "Password required" : "Salasana vaaditaan",
    "Testing authentication" : "Testataan tunnistautumista",
    "Awaiting user consent" : "Odotetaan käyttäjän hyväksyntää",
    "Loading account" : "Ladataan tiliä",
    "Account updated" : "Tili päivitetty",
    "IMAP server is not reachable" : "IMAP-palvelin ei ole tavoitettavissa",
    "SMTP server is not reachable" : "SMTP-palvelin ei ole tavoitettavissa",
    "IMAP username or password is wrong" : "IMAP-käyttäjätunnus tai -salasana on väärin",
    "SMTP username or password is wrong" : "SMTP-käyttäjätunnus tai -salasana on väärin",
    "IMAP connection failed" : "IMAP-yhteys epäonnistui",
    "SMTP connection failed" : "SMTP-yhteys epäonnistui",
    "Authorization pop-up closed" : "Valtuutusikkuna suljettu",
    "There was an error while setting up your account" : "Tiliä määrittäessä ilmeni virhe",
    "Auto" : "Automaattinen",
    "Name" : "Nimi",
    "Mail address" : "Sähköpostiosoite",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Kirjoita sähköpostiosoite muiodossa name@example.com",
    "Password" : "Salasana",
    "Manual" : "Manuaalinen",
    "IMAP Settings" : "IMAP-asetukset",
    "IMAP Host" : "IMAP-palvelin",
    "IMAP Security" : "IMAP-tietoturva",
    "None" : "Ei mitään",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-portti",
    "IMAP User" : "IMAP-käyttäjä",
    "IMAP Password" : "IMAP-salasana",
    "SMTP Settings" : "SMTP-asetukset",
    "SMTP Host" : "SMTP-palvelin",
    "SMTP Security" : "SMTP-tietoturva",
    "SMTP Port" : "SMTP-portti",
    "SMTP User" : "SMTP-käyttäjä",
    "SMTP Password" : "SMTP-salasana",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Google-tilin toiminta tämän sovelluksen kanssa vaatii, että otat kaksivaiheisen todennuksen käyttöön Googlessa ja luot sovelluksen salasanan.",
    "Account settings" : "Tilin asetukset",
    "Aliases" : "Aliakset",
    "Signature" : "Allekirjoitus",
    "A signature is added to the text of new messages and replies." : "Allekirjoitus lisätään uusien viestien ja vastausten tekstiosaan.",
    "Writing mode" : "Kirjoitustila",
    "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
    "Default folders" : "Oletuskansiot",
    "Autoresponder" : "Automaattivastaukset",
    "Go to Sieve settings" : "Siirry Sieve-asetuksiin",
    "Filters" : "Suodattimet",
    "Quick actions" : "Pikatoiminnot",
    "Mail server" : "Sähköpostipalvelin",
    "Sieve server" : "Sieve-palvelin",
    "Update alias" : "Päivitä alias",
    "Delete alias" : "Poista alias",
    "Go back" : "Takaisin",
    "Change name" : "Vaihda nimi",
    "Email address" : "Sähköpostiosoite",
    "Add alias" : "Lisää alias",
    "Create alias" : "Luo alias",
    "Cancel" : "Peruuta",
    "Could not update preference" : "Asetuksia ei voitu päivittää",
    "Mail settings" : "Sähköpostin asetukset",
    "General" : "Yleiset",
    "Add mail account" : "Lisää sähköpostitili",
    "Appearance" : "Ulkoasu",
    "Layout" : "Asettelu",
    "List" : "Lista",
    "Vertical split" : "Pystysuunnan jako",
    "Horizontal split" : "Vaakasuunnan jako",
    "Sorting" : "Lajittelu",
    "Newest first" : "Uusin ensin",
    "Oldest first" : "Vanhin ensin",
    "Show all messages in thread" : "Näytä kaikki viestit ketjussa",
    "Search in body" : "Etsi sisällöstä",
    "Gravatar settings" : "Gravatar-asetukset",
    "Register" : "Rekisteröidy",
    "Text blocks" : "Tekstilohkot",
    "New text block" : "Uusi tekstilohko",
    "Shared with me" : "Jaettu kanssasi",
    "Privacy and security" : "Yksityisyys ja turvallisuus",
    "Security" : "Tietoturva",
    "S/MIME" : "S/MIME",
    "Manage certificates" : "Hallitse varmenteita",
    "About" : "Tietoja",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Compose new message" : "Uusi viesti",
    "Newer message" : "Uudempi",
    "Older message" : "Vanhempi viesti",
    "Toggle star" : "Lisää/poista tähti",
    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
    "Archive" : "Arkisto",
    "Delete" : "Poista",
    "Search" : "Etsi",
    "Send" : "Lähetä",
    "Refresh" : "Päivitä",
    "Title of the text block" : "Tekstilohkon otsikko",
    "Content of the text block" : "Tekstilohkon sisältö",
    "Ok" : "Ok",
    "No certificate" : "Ei varmennetta",
    "Certificate updated" : "Varmenne päivitetty",
    "Could not update certificate" : "Varmennetta ei voitu päivittää",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Kelvollinen {expiryDate} asti",
    "Update Certificate" : "Päivitä varmenne",
    "Encrypt with S/MIME and send later" : "Salaa S/MIME:llä ja lähetä myöhemmin",
    "Encrypt with S/MIME and send" : "Salaa S/MIME:llä ja lähetä",
    "Encrypt with Mailvelope and send later" : "Salaa Mailvelopella ja lähetä myöhemmin",
    "Encrypt with Mailvelope and send" : "Salaa Mailvelopella ja lähetä",
    "Send later" : "Lähetä myöhemmin",
    "Message {id} could not be found" : "Viestiä {id} ei löytynyt",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Mikä tahansa aiempi muotoilu (esimerkiksi lihavointi, kursivointi, alleviivaus tai sisennetyt kuvat) poistetaan.",
    "Turn off formatting" : "Poista muotoilu käytöstä",
    "Turn off and remove formatting" : "Poista käytöstä ja poista muotoilu",
    "Keep formatting" : "Säilytä muotoilu",
    "From" : "Lähettäjä",
    "Select account" : "Valitse tili",
    "To" : "Vastaanottaja",
    "Select recipient" : "Valitse vastaanottaja",
    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Aihe",
    "Subject …" : "Aihe…",
    "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Seuraavilla vastaanottajilla ei ole S/MIME-varmennetta: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
    "Write message …" : "Kirjoita viesti…",
    "Saving draft …" : "Tallennetaan luonnosta…",
    "Error saving draft" : "Virhe tallentaessa luonnosta",
    "Draft saved" : "Luonnos tallennettu",
    "Save draft" : "Tallenna luonnos",
    "Discard & close draft" : "Hylkää ja sulje luonnos",
    "Enable formatting" : "Käytä muotoilua",
    "Disable formatting" : "Poista muotoilu käytöstä",
    "Upload attachment" : "Lähetä liite",
    "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
    "Request a read receipt" : "Pyydä lukukuittaus",
    "Sign message with S/MIME" : "Allekirjoita viesti S/MIME:llä",
    "Encrypt message with S/MIME" : "Salaa viesti S/MIME:llä",
    "Encrypt message with Mailvelope" : "Salaa viesti Mailvelopella",
    "Send now" : "Lähetä nyt",
    "Tomorrow morning" : "Huomenna aamulla",
    "Tomorrow afternoon" : "Huomenna iltapäivällä",
    "Monday morning" : "Maanantaiaamuna",
    "Custom date and time" : "Omavalintainen päivä ja aika",
    "Enter a date" : "Kirjoita päiväys",
    "Choose" : "Valitse",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Liite ylittää sallitun enimmäiskoon {size}. Jaa tiedosto linkin kautta.","Liitteet ylittävät sallitun enimmäiskoon {size}. Jaa tiedostot linkin kautta."],
    "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
    "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
    "_{count} attachment_::_{count} attachments_" : ["{count} liite","{count} liitettä"],
    "Untitled message" : "Nimetön viesti",
    "Expand composer" : "Laajenna lähetysikkunaa",
    "Close composer" : "Sulje lähetysikkuna",
    "Confirm" : "Vahvista",
    "Plain text" : "Raakateksti",
    "Rich text" : "Rikas teksti",
    "No messages in this folder" : "Tässä kansiossa ei ole viestejä",
    "No messages" : "Ei viestejä",
    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
    "No subject" : "Ei aihetta",
    "{markup-start}Draft:{markup-end} {subject}" : "{markup-start}Luonnos:{markup-end} {subject}",
    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
    "Could not execute quick action" : "Pikatoimintoa ei voitu suorittaa",
    "Quick action executed" : "Pikatoiminto suoritettu",
    "Could not delete message" : "Ei voitu poistaa viestiä",
    "Could not archive message" : "Viestiä ei voitu arkistoida",
    "This summary was AI generated" : "Tämä yhteenveto on tekoälyn luoma",
    "Encrypted message" : "Salattu viesti",
    "This message is unread" : "Tämä viesti on lukematon",
    "Unfavorite" : "Poista suosikeista",
    "Favorite" : "Suosikki",
    "Unread" : "Lukematon",
    "Read" : "Lue",
    "Unimportant" : "Ei tärkeä",
    "Mark not spam" : "Merkitse ei roskapostiksi",
    "Mark as spam" : "Merkitse roskapostiksi",
    "Edit tags" : "Muokkaa tunnisteita",
    "Snooze" : "Torkuta",
    "Move thread" : "Siirrä ketju",
    "Move Message" : "Siirrä viesti",
    "Archive thread" : "Arkistoi ketju",
    "Archive message" : "Arkistoi viesti",
    "Delete thread" : "Poista ketju",
    "Delete message" : "Poista viesti",
    "More actions" : "Lisää toimintoja",
    "Back" : "Takaisin",
    "Set custom snooze" : "Aseta mukautettu torkutus",
    "Edit as new message" : "Muokkaa uutena viestinä",
    "Create task" : "Luo tehtävä",
    "Download message" : "Lataa viesti",
    "Manage quick actions" : "Hallitse pikatoimintoja",
    "Load more" : "Lataa lisää",
    "_Mark {number} read_::_Mark {number} read_" : ["Merkitse {number} luetuksi","Merkitse {number} luetuksi"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Merkitse {number} lukemattomaksi","Merkitse {number} lukemattomaksi"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Merkitse {number} tärkeäksi","Merkitse {number} tärkeäksi"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Merkitse {number} roskapostiksi","Merkitse {number} roskapostiksi"],
    "_Move {number} thread_::_Move {number} threads_" : ["Siirrä {number} ketju","Siirrä {number} ketjua"],
    "Mark as unread" : "Merkitse lukemattomaksi",
    "Mark as read" : "Merkitse luetuksi",
    "Report this bug" : "Ilmoita viasta",
    "Event created" : "Tapahtuma luotu",
    "Could not create event" : "Tapahtumaa ei voitu luoda",
    "Create event" : "Luo tapahtuma",
    "All day" : "Koko päivä",
    "Attendees" : "Osallistujat",
    "Select calendar" : "Valitse kalenteri",
    "Description" : "Kuvaus",
    "Create" : "Luo",
    "This event was updated" : "Tämä tapahtuma päivitettiin",
    "{attendeeName} accepted your invitation" : "{attendeeName} hyväksyi kutsusi",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} hyväksyi kutsusi alustavasti",
    "{attendeeName} declined your invitation" : "{attendeeName} kieltäytyi kutsustasi",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reagoi kutsuusi",
    "You accepted this invitation" : "Hyväksyit tämän kutsun",
    "You tentatively accepted this invitation" : "Hyväksyit tämän kutsun alustavasti",
    "You declined this invitation" : "Kieltäydyit tästä kutsusta",
    "You already reacted to this invitation" : "Reagoit jo tähän kutsuun",
    "You have been invited to an event" : "Sinut on kutsuttu tapahtumaan",
    "This event was cancelled" : "Tämä tapahtuma peruttiin",
    "Select" : "Valitse",
    "Comment" : "Kommentti",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Tentatively accept" : "Alustavasti hyväksytty",
    "More options" : "Lisää valintoja",
    "Could not remove internal address {sender}" : "Ei voitu poistaa sisäistä osoitetta {sender}",
    "Could not add internal address {address}" : "Ei voitu lisätä sisäistä osoitetta {address}",
    "individual" : "yksittäinen",
    "domain" : "domaini",
    "Remove" : "Poista",
    "email" : "sähköposti",
    "Add internal address" : "Lisää sisäinen osoite",
    "Last hour" : "Viime tunti",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "Last week" : "Viime viikko",
    "Last month" : "Viime kuukausi",
    "Could not open folder" : "Kansiota ei voitu avata",
    "Loading messages …" : "Ladataan viestejä …",
    "Choose target folder" : "Valitse kohdekansio",
    "Important info" : "Tärkeää tietoa",
    "Other" : "Muu",
    "The sender of this message has asked to be notified when you read this message." : "Tämän viestin lähettäjä on pyytänyt ilmoitusta, kun luet tämän viestin.",
    "Notify the sender" : "Ilmoita lähettäjälle",
    "You sent a read confirmation to the sender of this message." : "Lähetit lukukuittauksen tämän viestin lähettäjälle.",
    "Forward" : "Lähetä edelleen",
    "Move message" : "Siirrä viesti",
    "Translate" : "Käännä",
    "Forward message as attachment" : "Välitä viesti liitteenä",
    "View source" : "Näytä lähde",
    "Print message" : "Tulosta viesti",
    "Create mail filter" : "Luo viestisuodatin",
    "Download thread data for debugging" : "Lataa ketjun data vianjäljitystä varten",
    "Message body" : "Viestin runko",
    "Unnamed" : "Nimetön",
    "Embedded message" : "Upotettu viesti",
    "calendar imported" : "kalenteri tuotu",
    "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
    "Import into calendar" : "Tuo kalenteriin",
    "Download attachment" : "Lataa liite",
    "Save to Files" : "Tallenna tiedostoihin",
    "View fewer attachments" : "Näytä vähemmän liitteitä",
    "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
    "Save all to Files" : "Tallenna kaikki tiedostoihin",
    "Download Zip" : "Lataa Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Näytä {count} liite lisää","Näytä {count} liitettä lisää"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tämä viesti on salattu PGP:llä. Asenna Mailvelope purkaaksesi viestin salauksen.",
    "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
    "Show images" : "Näytä kuvat",
    "Show images temporarily" : "Näytä kuvat väliaikaisesti",
    "Always show images from {sender}" : "Näytä aina kuvat lähettäjältä {sender}",
    "Always show images from {domain}" : "Näytä aina kuvat verkkotunnuksesta {domain}",
    "Message frame" : "Viestiruutu",
    "Quoted text" : "Lainattu teksti",
    "Move" : "Siirrä",
    "Moving" : "Siirretään",
    "Moving thread" : "Siirretään ketjua",
    "Moving message" : "Siirretään viestiä",
    "Used quota: {quota}% ({limit})" : "Käytetty kiintiö: {quota}% ({limit})",
    "Used quota: {quota}%" : "Käytetty kiintiö: {quota}%",
    "Remove account" : "Poista tili",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
    "Remove {email}" : "Poista {email}",
    "Show only subscribed folders" : "Näytä vain tilatut kansiot",
    "Add folder" : "Lisää kansio",
    "Folder name" : "Kansion nimi",
    "Saving" : "Tallennetaan",
    "Move up" : "Siirrä ylös",
    "Move down" : "Siirrä alas",
    "Show all subscribed folders" : "Näytä kaikki tilatut kansiot",
    "Show all folders" : "Näytä kaikki kansiot",
    "Collapse folders" : "Supista kansiot",
    "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
    "Loading …" : "Ladataan…",
    "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
    "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
    "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
    "Delete folder" : "Poista kansio",
    "Delete folder {name}" : "Poista kansio {name}",
    "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
    "Mark all as read" : "Merkitse kaikki luetuiksi",
    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
    "Add subfolder" : "Lisää alikansio",
    "Rename" : "Nimeä uudelleen",
    "Move folder" : "Siirrä kansio",
    "Clear cache" : "Tyhjennä välimuisti",
    "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
    "Subscribed" : "Tilattu",
    "Sync in background" : "Synkronoi taustalla",
    "New message" : "Uusi viesti",
    "Edit message" : "Muokkaa viestiä",
    "Draft" : "Luonnos",
    "Reply" : "Vastaa",
    "Message saved" : "Viesti tallennettu",
    "Failed to save message" : "Viestin tallentaminen epäonnistui",
    "Failed to save draft" : "Luonnoksen tallentaminen epäonnistui",
    "Message discarded" : "Viesti hylätty",
    "Could not discard message" : "Viestiä ei voitu hylätä",
    "Minimize composer" : "Pienennä lähetysikkuna",
    "Error sending your message" : "Virhe viestiäsi lähettäessä",
    "Retry" : "Yritä uudelleen",
    "Warning sending your message" : "Varoitus viestiä lähettäessä",
    "Send anyway" : "Lähetä silti",
    "Welcome to {productName} Mail" : "Tervetuloa {productName}-sähköpostiin ",
    "Autoresponder off" : "Automaattivastaukset pois päältä",
    "Autoresponder on" : "Automaattivastaukset päällä",
    "Edit absence settings" : "Muokkaa poissaoloasetuksia",
    "First day" : "Ensimmäinen päivä",
    "Last day (optional)" : "Viimeinen päivä (valinnainen)",
    "Message" : "Viesti",
    "Oh Snap!" : "Oho!",
    "Save autoresponder" : "Tallenna automaattivastaus",
    "Pending or not sent messages will show up here" : "Odottavat tai vielä lähettämättömät viestit näkyvät täällä",
    "Mail server error" : "Sähköpostipalvelimen virhe",
    "Message could not be sent" : "Viestiä ei voitu lähettää",
    "Message deleted" : "Viesti poistettu",
    "Phishing email" : "Kalasteluviesti",
    "This email might be a phishing attempt" : "Tämä viesti saattaa olla kalasteluyritys",
    "Hide suspicious links" : "Piilota epäilyttävät linkit",
    "Show suspicious links" : "Näytä epäilyttävät linkit",
    "link text" : "linkin teksti",
    "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
    "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
    "Contacts with this address" : "Yhteystiedot tällä osoitteella",
    "Add to Contact" : "Lisää yhteystietoon",
    "New Contact" : "Uusi yhteystieto",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Contact name …" : "Yhteystiedon nimi…",
    "Add" : "Lisää",
    "Show less" : "Näytä vähemmän",
    "Show more" : "Näytä enemmän",
    "Clear" : "Tyhjennä",
    "Search in folder" : "Etsi kansiosta",
    "Close" : "Sulje",
    "Body" : "Sisältö",
    "Date" : "Päivä",
    "Pick a start date" : "Valitse aloituspäivä",
    "Pick an end date" : "Valitse päättymispäivä",
    "Tags" : "Tunnisteet",
    "Select tags" : "Valitse tunnisteet",
    "Has attachments" : "On liitteitä",
    "Last 7 days" : "Edelliset 7 päivää",
    "Sieve Port" : "Sieve-portti",
    "IMAP credentials" : "IMAP-tunnukset",
    "Custom" : "Omavalintainen",
    "Sieve User" : "Sieve-käyttäjä",
    "Sieve Password" : "Sieve-salasana",
    "Save sieve settings" : "Tallenna sieve-asetukset",
    "The syntax seems to be incorrect:" : "Syntaksi vaikuttaa virheelliseltä:",
    "Signature …" : "Allekirjoitus…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
    "Save signature" : "Tallenna allekirjoitus",
    "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
    "Message source" : "Viestin lähde",
    "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
    "Edit name or color" : "Muokkaa nimeä tai väriä",
    "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
    "Delete tag" : "Poista tunniste",
    "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
    "Tag already exists" : "Tunniste on jo olemassa",
    "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
    "Add default tags" : "Lisää oletustunnisteet",
    "Add tag" : "Lisää tunniste",
    "Saving tag …" : "Tallennetaan tunnistetta…",
    "Task created" : "Tehtävä luotu",
    "Could not create task" : "Tehtävää ei voitu luoda",
    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
    "The thread doesn't exist or has been deleted" : "Ketjua ei ole olemassa tai se on poistettu",
    "Print" : "Tulosta",
    "Could not print message" : "Viestiä ei voitu tulostaa",
    "Loading thread" : "Ladataan ketjua",
    "Not found" : "Ei löytynyt",
    "Encrypted & verified " : "Salattu ja vahvistettu",
    "Signature verified" : "Allekirjoitus vahvistettu",
    "Signature unverified " : "Allekirjoitus vahvistamatta",
    "This message was encrypted by the sender before it was sent." : "Tämän viestin lähettäjä salasi viestin ennen sen lähettämistä.",
    "Reply all" : "Vastaa kaikille",
    "Unsubscribe request sent" : "Tilauksen lopetuspyyntö lähetetty",
    "Disable reminder" : "Poista muistutus käytöstä",
    "Unsubscribe" : "Peruuta tilaus",
    "Reply to sender only" : "Vastaa vain lähettäjälle",
    "Mark as favorite" : "Merkitse suosikiksi",
    "Unsubscribe via link" : "Lopeta tilaus linkin kautta",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Tilauksen lopettaminen pysäyttää kaikkien viestin saapumisen postituslistalta {sender}",
    "Send unsubscribe email" : "Lähetä viesti tilauksen lopettamiseksi",
    "Unsubscribe via email" : "Lopeta tilaus sähköpostiviestin välityksellä",
    "Go to latest message" : "Siirry uusimpaan viestiin",
    "Newest message" : "Uusin viesti",
    "The message could not be translated" : "Viestiä ei voitu kääntää",
    "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
    "Translation could not be copied" : "Käännöstä ei voitu kopioida",
    "Translate message" : "Käännä viesti",
    "Source language to translate from" : "Lähdekieli, josta käännetään",
    "Translate from" : "Lähdekieli",
    "Target language to translate into" : "Kohdekieli, jolle käännetään",
    "Translate to" : "Kohdekieli",
    "Translating" : "Käännetään",
    "Copy translated text" : "Kopioi käännetty teksti",
    "Could not remove trusted sender {sender}" : "Ei voitu poistaa luotettua lähettäjää {sender}",
    "No senders are trusted at the moment." : "Ei luotettuja lähettäjiä tällä hetkellä.",
    "Untitled event" : "Nimetön tapahtuma",
    "(organizer)" : "(järjestäjä)",
    "Import into {calendar}" : "Tuo kalenteriin {calendar}",
    "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lento {flightNr} lentokentältä {depAirport} lentokentälle {arrAirport}",
    "Airplane" : "Lentokone",
    "Reservation {id}" : "Varaus {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
    "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
    "Train" : "Juna",
    "Stop" : "Pysäytä",
    "Delete action" : "Poista toiminto",
    "Sender" : "Lähettäjä",
    "Recipient" : "Vastaanottaja",
    "Create a new mail filter" : "Luo uusi viestisuodatin",
    "Delete filter" : "Poista suodatin",
    "Delete mail filter {filterName}?" : "Poistetaanko viestisuodatin {filterName}?",
    "Are you sure to delete the mail filter?" : "Haluatko varmasti poistaa viestisuodattimen?",
    "New filter" : "Uusi suodatin",
    "Filter saved" : "Suodatin tallennettu",
    "Could not save filter" : "Suodatinta ei voitu tallentaa",
    "Filter deleted" : "Suodatin poistettu",
    "Could not delete filter" : "Suodatinta ei voitu poistaa",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Ota postikaaos hallintaan. Suodattimet auttavat asettamaan asioita tärkeysjärjestykseen ja minimoimaan turhuudet.",
    "Filter is active" : "Suodatin on aktiivinen",
    "Filter is not active" : "Suodatin ei ole aktiivinen",
    "Help" : "Ohje",
    "contains" : "sisältää",
    "matches" : "täsmää",
    "Add condition" : "Lisää ehto",
    "Actions" : "Toiminnot",
    "Add action" : "Lisää toiminto",
    "Priority" : "Tärkeys",
    "Enable filter" : "Käytä suodatinta",
    "Tag" : "Tunniste",
    "delete" : "poista",
    "Edit quick action" : "Muokkaa pikatoimintoa",
    "Add quick action" : "Lisää pikatoiminto",
    "Quick action deleted" : "Pikatoiminto poistettu",
    "Failed to delete quick action" : "Pikatoiminnon poisto epäonnistui",
    "Failed to update quick action" : "Pikatoiminnon päivitys epäonnistui",
    "Quick action updated" : "Pikatoiminto päivitetty",
    "Failed to create quick action" : "Pikatoiminnon luonti epäonnistui",
    "Quick action created" : "Pikatoiminto luotu",
    "No quick actions yet." : "Ei pikatoimintoja vielä",
    "Edit" : "Muokkaa",
    "Quick action name" : "Pikatoiminnon nimi",
    "Do the following actions" : "Tee seuraavat toiminnot",
    "Add another action" : "Lisää toinen toiminto",
    "Mail app" : "Sähköpostisovellus",
    "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
    "Account provisioning" : "Käyttäjän provisiointi",
    "Provisioning Configurations" : "Provisiointi-asetukset",
    "Add new config" : "Lisää uusi asetus",
    "Provision all accounts" : "Provisioidaan kaikki käyttäjät",
    "Anti Spam Service" : "Roskapostin estopalvelu",
    "Gmail integration" : "Gmail-integraatio",
    "Microsoft integration" : "Microsoft-integraatio",
    "Message View Mode" : "Viestin näyttötapa",
    "Show only the selected message" : "Näytä vain valittu viesti",
    "Anti Spam" : "Roskapostin esto",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
    "Reset" : "Palauta",
    "Google integration configured" : "Google-integraatio määritetty",
    "Could not configure Google integration" : "Google-integraatiota ei voitu määrittää",
    "Google integration unlinked" : "Google-integraation linkitys poistettu",
    "Client ID" : "Asiakas-ID",
    "Client secret" : "Asiakassalasana",
    "Unlink" : "Poista linkitys",
    "Microsoft integration configured" : "Microsoft-integraatio määritetty",
    "Could not configure Microsoft integration" : "Microsoft-integraatiota ei voitu määrittää",
    "Email: {email}" : "Sähköposti: {email}",
    "IMAP" : "IMAP",
    "User" : "Käyttäjä",
    "Host" : "Palvelin",
    "Port" : "Portti",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "LDAP aliases integration" : "LDAP-aliasten integraatio",
    "Enable LDAP aliases integration" : "Käytä LDAP-aliasten integraatiota",
    "Save Config" : "Tallenna asetus",
    "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
    "Certificate imported successfully" : "Varmenne tuotu onnistuneesti",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Varmenteen tuonti epäonnistui. Varmista, että yksityinen avain vastaa varmennetta ja ettei se ole suojattu tunnuslauseella.",
    "Failed to import the certificate" : "Varmenteen tuominen epäonnistui",
    "S/MIME certificates" : "S/MIME-varmenteet",
    "Certificate name" : "Varmenteen nimi",
    "E-mail address" : "Sähköpostiosoite",
    "Valid until" : "Kelvollinen",
    "Delete certificate" : "Poista varmenne",
    "No certificate imported yet" : "Varmennetta ei ole vielä tuotu",
    "Import certificate" : "Tuo varmenne",
    "Import S/MIME certificate" : "Tuo S/MIME-varmenne",
    "PKCS #12 Certificate" : "PKCS #12 -varmenne",
    "PEM Certificate" : "PEM-varmenne",
    "Certificate" : "Varmenne",
    "Private key (optional)" : "Yksityinen avain (valinnainen)",
    "Submit" : "Lähetä",
    "No text blocks available" : "Tekstilohkoja ei ole saatavilla",
    "Text block deleted" : "Tekstilohko poistettu",
    "Failed to delete text block" : "Tekstilohkon poisto epäonnistui",
    "Guest" : "Vieras",
    "Group" : "Ryhmä",
    "Failed to save text block" : "Tekstilohkon tallennus epäonnistui",
    "Shared" : "Jaettu",
    "Edit {title}" : "Muokkaa {title}",
    "Delete {title}" : "Poista {title}",
    "Edit text block" : "Muokkaa tekstilohkoa",
    "Shares" : "Jaot",
    "Search for users or groups" : "Etsi käyttäjiä tai ryhmiä",
    "Insert" : "Lisää",
    "Insert text block" : "Lisää tekstilohko",
    "Account connected" : "Tili yhdistetty",
    "You can close this window" : "Voit sulkea tämän ikkunan",
    "Connect your mail account" : "Yhdistä sähköpostitilisi",
    "To add a mail account, please contact your administrator." : "Ole yhteydessä ylläpitoon lisätäksesi sähköpostitilin.",
    "All" : "Kaikki",
    "Drafts" : "Luonnokset",
    "Favorites" : "Suosikit",
    "Priority inbox" : "Tärkeät saapuneet",
    "All inboxes" : "Kaikki saapuneiden laatikot",
    "Inbox" : "Saapuneet",
    "Junk" : "Roskaposti",
    "Sent" : "Lähetetyt",
    "Trash" : "Roskakori",
    "Connect OAUTH2 account" : "Yhdistä OAUTH2-tili",
    "Error while sharing file" : "Virhe tiedostoa jakaessa",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
    "Nextcloud Mail" : "Nextcloud-sähköposti",
    "Discard changes" : "Hylkää muutokset",
    "Discard unsaved changes" : "Hylkää tallentamattomat muutokset",
    "Keep editing message" : "Jatka viestin muokkausta",
    "Attachments were not copied. Please add them manually." : "Liitetiedostoja ei kopiotu. Lisää ne manuaalisesti.",
    "Sending message…" : "Lähetetään viestiä…",
    "Message sent" : "Viesti lähetetty",
    "Could not send message" : "Viestiä ei voitu lähettää",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
    "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
    "Could not load your message" : "Viestiä ei voitu ladata",
    "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
    "Could not load the message" : "Viestiä ei voitu ladata",
    "Error loading message" : "Virhe viestiä ladatessa",
    "Forwarding to %s" : "Välitä viesti %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
    "Redirect" : "Uudelleenohjaus",
    "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
    "Continue to %s" : "Jatka sivulle %s",
    "Put my text to the bottom of a reply instead of on top of it." : "Aseta tekstini vastauksen alaosaan yläosan sijaan",
    "Accounts" : "Tilit",
    "Newest" : "Uusimmat",
    "Oldest" : "Vanhimmat",
    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
    "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
    "Create a new text block" : "Luo uusi tekstilohko",
    "Data collection consent" : "Datakeruun suostumus",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
    "Trusted senders" : "Luotetut lähettäjät",
    "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
    "Step 1: Install Mailvelope browser extension" : "Vaihe 1: Asenna Mailvelope-selainlaajennus",
    "Step 2: Enable Mailvelope for the current domain" : "Vaihe 2: Ota Mailvelope käyttöön nykyiselle verkkotunnukselle"
},
"nplurals=2; plural=(n != 1);");
